# Copyright 2019 DeepMind Technologies Limited. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# ==============================================================================
"""Tests for importing optax."""

from absl.testing import absltest
import optax
from optax import transforms


class OptaxTest(absltest.TestCase):
  """Test optax can be imported correctly."""

  def test_import(self):
    self.assertTrue(hasattr(optax, 'GradientTransformation'))
    self.assertTrue(hasattr(transforms, 'partition'))


if __name__ == '__main__':
  absltest.main()
